#include "FBF.h"

#include <stdio.h>

/* STL tools */
#include <string>


/* STDC tools */
#include <unistd.h> /* BYTE_ORDER */
#include <ctype.h>  /* tolower, toupper */
#include <glob.h>   /* glob */


/* byte order sensitive parts */
#if BYTE_ORDER == LITTLE_ENDIAN
#define tonative tolower
#elif BYTE_ORDER == BIG_ENDIAN
#define tonative toupper
#else
#warning BYTE_ORDER is unknown - assuming big endian
#define tonative toupper
#endif



namespace FBF { 

        
#define OS_PATH_SEP '/'
    
    const char *filename( const char *path ) 
{
        const char *sep = strrchr( path, OS_PATH_SEP ); 
        return sep? sep : path;
}	


const char *nativeFilename( char *buffer )
{ /* fixes a filename buffer to match the native word order */
//printf( "nativizing %s\n", buffer );
char *suffix = strchr( buffer, '.' );
if (!suffix) return buffer;
for( suffix++; isalpha( *suffix ); suffix++ )
*suffix = tonative( *suffix );
//printf( "changed to  %s\n", buffer );

return buffer;
}

std::string nativeFilename( const std::string &str )
{
    char buffer[ str.size() ];
    strcpy( buffer, str.c_str() );
    nativeFilename( buffer );
    return std::string( buffer );
}

int firstFilename( std::string &out, const char *pattern )
{ /* returns name of the first file that matches the pattern */
glob_t matches;
int rc = 0;
bzero( &matches, sizeof(matches) );

int result = glob( pattern, GLOB_ERR | GLOB_TILDE, 0, &matches );
if (result!=0 || 0==matches.gl_pathc) 
{    
    rc = -1; goto bail; 
}

out = std::string( matches.gl_pathv[0] );

bail:
globfree( &matches );
return rc;
}



}; /* namespace */

