/**
 * \file Instrument.h
 * \brief contains common definitions of data structures shared by the various operators, stages and connectors
 * \author Ray Garcia <rayg@ssec.wisc.edu>, Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 *  \version $Id: Instrument.h,v 1.10 2004/10/31 05:07:39 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */

/// \mainpage
/// The common package contains utility classes, definitions and declarations 
/// used throughout the rest of the GIPS codebase.

#ifndef H_INSTRUMENT
#define H_INSTRUMENT


#ifndef NO_DEPENDENCY_INCLUDES

/* standard library dependencies */
#include <complex>

/* Third party includes */
#include <blitz/array.h>

/* local dependencies */

#endif // NO_DEPENDENCY_INCLUDES


namespace Instrument
{

    enum ObservationType_t { SCENE, HOT, AMBIENT, SPACE };
    enum Band { LW, SMW };
    enum Implementation { SHIS, NASTI, GIFTS_A, GIFTS_B }; // alternative labels to pass to the factories

    
    typedef unsigned int DetectorIndex_t;

    typedef blitz::Array<float,1> BlitzRealFloatVector;
    typedef blitz::Array<double,1> BlitzRealDoubleVector;
    
    typedef blitz::Array<std::complex<float>,1> BlitzCplxFloatVector;
    typedef blitz::Array<std::complex<double>,1> BlitzCplxDoubleVector;
    
    typedef blitz::Array<std::complex<float>,2> BlitzCplxFloatMatrix;
    typedef blitz::Array<std::complex<double>,2> BlitzCplxDoubleMatrix;
    
    
//    /* data type for elements of input and output spectra */
//#ifdef USE_SINGLE_PRECISION
//    typedef float data_t; 
//#else
//    typedef double data_t;
//#endif
//       
//    typedef data_t real_data_t;
//    typedef std::complex<double> complex_double;
    
    
//    /** Complex type used for realtime data.
//    *
//   */
//    typedef std::complex<data_t> complex_data_t;
    
    
    /** Input vector with nonlinear uncalibrated radiance data 
        * Units: counts
        */
    

// Legacy. Keep here for visual reference
    /** Output vector with nonlinear uncalibrated radiance data 
        * Units: counts
        */
//    typedef blitz::Array<complex_data_t,1> LinearSpectrum;
    
    /** Correction Bin
        * Effectively a key into the reference database. 
        * Expect that this will be used as a key for local computation caches.
        * Units: none.
        */
//    typedef unsigned long DetectorIndex_t;
// more entries from RadCal...
    
    /** Input vector containing complex uncalibrated radiance data 
        * Units: (complex) counts
        */
//    typedef blitz::Array<complex_data_t,1> UncalibratedSpectrum;
    
    /** Input vector containing (wavenumber dependent) telescope transmittance 
        * Units: (real) ???
        */
//    typedef blitz::Array<real_data_t,1> TelescopeTransmittance;
    
    
    /** Output vector containing (real) calibrated radiance data 
        * Units: radiance units [milliwatts/(meters^2 * steradians * inverse_cm)]
        */
//    typedef blitz::Array<real_data_t,1> CalibratedSpectrum;
    
    
    /** Diagnostic output vector - the imaginary component of the calibration equation  
        * Ideally, the imaginary component should contain only noise - any signal in this component
        * indicates a problem. 
        * Units: counts
        */
//    typedef blitz::Array<real_data_t,1> DiagnosticImaginarySpectrum; 
    
    
    
    
} // namespace Instrument
    
    
#endif

