/*
 * \file CplxFFT.cc
 * \brief SHIS implementation of CplxFFT operator
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 * based directly on the Scanning-HIS rsh2fbf application, written by Ray Garcia <rayg@ssec.wisc.edu>
 *
 *  \version $Id: CplxFFT.cc,v 1.16 2004/12/17 20:59:21 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */


#include "CplxFFT.h"
#include <iostream>

namespace CplxFFT
{


CplxFFTOperator::CplxFFTOperator(Ports &p): ports(p)
{
    const Config_t &config(ports.config);
    plan = fftw_create_plan( config.npts, FFTW_FORWARD, FFTW_MEASURE ); // alt: FFTW_ESTIMATE
    
    fftw_threads_init();    
}; // ctor

CplxFFTOperator::~CplxFFTOperator() {
    fftw_destroy_plan( plan );
}


Operator::Result CplxFFTOperator::operator() ( )
{
    // obtain underlying blitz vectors from I/O ports
    const Instrument::BlitzCplxDoubleVector si(ports.shiftedInterferogram.getForInput());
    Instrument::BlitzCplxDoubleVector pfs(ports.prefoldedSpectrum.getForOutput());
    
    
    // unfortunate casting required to FFTW-compatible types
    fftw_complex *spectrum_out = (fftw_complex *)(pfs.data());
    fftw_complex *interferogram_in = (fftw_complex *)(si.data());

    // std::cerr << "ifg in length: " << si.size() << " spec out length: " << pfs.size() << "\n";
    // std::cerr << "FFT input channels 0,10,200: " << si(0) << "," << si(10) << "," << si(200) << "\n";
    // not using the threaded version due to compilation errors
    fftw_one( plan, interferogram_in, spectrum_out );
    // std::cerr << "FFT output channels 0,10,200: " << pfs(0) << "," << pfs(10) << "," << pfs(200) << "\n";

    return Operator::OK;
}

} // namespace


