/**
 * \file IfgShift.cc
 * \brief SHIS implementation of IfgShift operator
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 * based directly on the Scanning-HIS rsh2fbf application, written by Ray Garcia <rayg@ssec.wisc.edu>
 *
 *  \version $Id: IfgShift.cc,v 1.12 2004/10/31 05:07:39 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */


#include "IfgShift.h"

namespace IfgShift
{

Operator::Result IfgShiftOperator::operator() ( )
{
    const Instrument::BlitzCplxDoubleVector in( ports.unshiftedInterferogram.getForInput() );
    Instrument::BlitzCplxDoubleVector out( ports.shiftedInterferogram.getForOutput() );
    const Config_t &config( ports.config );

    size_t N = config.npts; // we're using std::cplx, not interleaving
    size_t halfN = N / 2;
    
    if ( !N || N%2 ) return Operator::ERROR;

    unsigned src, dest=0;
    // again, dealing this time with std::cplx members, not interleaved real/imag parts
    for( src = halfN; src<N; src++,dest++ ) {
        out(dest) = in(src);
    }
    for( src=0; src<halfN; src++, dest++ ) {
        out(dest) = in(src); 
    }    
    return Operator::OK;
}
    
    
}; // namespace


/******************** original function body in rsh2fbf:
int sol1IfgShift( solContent &mcontent, const solContent &C ) {
    size_t N = C.size()/2, halfN = N/2;    
    if (!N || N%2) return -1;
    mcontent.resize( C.size() ); // solContent inherits from std::vector
    size_t src, dest=0;
    // fftshift( data ) for complex data
    for( src = halfN; src<N; src++,dest++ ) {
        mcontent[dest*2] = C[src*2];
        mcontent[(dest*2)+1] = C[(src*2)+1];
    }
    for( src=0; src<halfN; src++, dest++ ) {
        mcontent[dest*2] = C[src*2]; 
        mcontent[(dest*2)+1] = C[(src*2)+1];
    }
    return 0;
}
*********************/

