/*
 * \file IfgShiftTest.cc
 * \brief unit test for IfgShift operator
 * \author Maciek Smuga-Otto <maciek@ssec.wisc.edu>
 *
 *  \version $Id: IfgShiftTest.cc,v 1.9 2004/10/31 05:07:39 maciek Exp $
 *
 *  \par Copyright:
 *  \verbatim
 *
 *  Copyright UW/SSEC, ALL RIGHTS RESERVED, 2004
 *  Space Science and Engineering Center
 *  University of Wisconsin - Madison, USA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  \endverbatim
 */


#include <iostream> // std::cerr
#include <cstring> // memset
#include <cstdlib> // exit
#include <cassert> // assert
#include <complex>

#include "IfgShift.h"
#include "TestConnector.h"

namespace IfgShift
{


/// \todo get the const stuff sorted out
Config_t defaultConfig( 1024 );

Operator::Result testOperator( )
{
    // data in & out
    blitz::Array< std::complex<double>, 2> blitzIn( 1, 1024 );
    Connector::BlitzMatrixBackedInputConnector< std::complex<double> > testIn( blitzIn );
    
    blitz::Array< std::complex<double>, 2> blitzOut( 1, 1024 );
    Connector::BlitzMatrixBackedOutputConnector< std::complex<double> > testOut( blitzOut );

    Connector::ConstantInputPort<Config_t> testConfig( defaultConfig );

    // invoke operator with the correct ports
    Ports ports( testIn, testOut, testConfig );

    IfgShiftOperator op( ports );
    Operator::Result res = op();
    
    return res;
}; // testOperator()

}; // namespace


int main( int argc, char *argv[] )
{
    Operator::Result rc = IfgShift::testOperator();
    assert( rc==Operator::OK );
    exit(0);
}

